# Class Hierarchy

- datetime.datetime
  - spamfighter.core.commands.serialize.DateTime - Наследник datetime.datetime, который требует в конструктор
- dict
  - spamfighter.core.model.thomas.BayesData - Undocumented
  - spamfighter.utils.config.Cfg - Класс в который мы заворачиваем хеш. Нужен для того, чтобы нормально отображать штуки типа config.db.dsn
- Exception
  - spamfighter.core.commands.errors.BaseCommandException - Базовое исключение при обработке команды
    - spamfighter.core.commands.errors.AttributeKeyException - Атрибут не найден в домене.
    - spamfighter.core.commands.errors.AuthorizationFailedException - Авторизация через партнера не удалась.
    - spamfighter.core.commands.errors.CommandParamsMissingException - Исключение об отсутствии параметров команды
    - spamfighter.core.commands.errors.CommandUnknownException - Исключение о неизвестной команде.
    - spamfighter.core.commands.errors.DomainPathNotFoundException - Указанный путь к домену не валиден.
    - spamfighter.core.commands.errors.FatalCommandException - Фатальная ошибка, приводящая к закрытию текущего соединения.
    - spamfighter.core.commands.errors.FirewallSyntaxError - Ошибка синтаксиса правил firewall.
    - spamfighter.core.commands.errors.InternalCommandException - Сообщение о внутренней ошибке сервера.
      - spamfighter.core.commands.errors.CommandResultMissingException - Исключение об отсутствии результата команды
      - spamfighter.core.commands.errors.UnexpectedException - Исключение об неизвестной ситуации при обработке команды
    - spamfighter.core.commands.errors.MessageAttributeKeyException - Атрибут не найден в сообщении.
    - spamfighter.core.commands.errors.NotAFirewallError - Указанный объект не является firewallом.
    - spamfighter.core.commands.errors.NotAMessageLogError - Указанный объект не является логом сообщений.
    - spamfighter.core.commands.errors.NotAModelError - Указанный объект не является моделью.
    - spamfighter.core.commands.errors.SkipToFallthroughError - В firewall не нашлось метки для skip to...
    - spamfighter.core.commands.errors.TypeParameterException - Исключение о передаче параметра неверного типа.
    - spamfighter.core.commands.errors.UnknownParameterException - Исключение о передаче неизвестного параметра для команды.
  - spamfighter.core.commands.serialize.SerializerNotFoundException - Не был найден подходящий десериализатор для переданного интерфейса.
  - spamfighter.core.domain.DomainDuplicateError - У данного домена уже есть поддомен с таким же именем.
  - spamfighter.core.domain.DomainKeyError - В данном домене нет указанного значения.
  - spamfighter.core.domain.DomainPathError - Указанный путь в поддоменах отсутствует.
  - spamfighter.core.firewall.FirewallResult - Служебное исключение, обработка цепочки правил
  - spamfighter.core.firewall.SkipToProcess - Служебное исключение, используется для "пропуска" правил
  - spamfighter.core.firewall.SyntaxError - Сообщение об ошибке в синтаксисе файрвола.
  - spamfighter.core.message.attribute.AttributeNotFoundError - Атрибут по имени не был обнаружен.
  - spamfighter.core.partner.PartnerAuthorizationFailedError - Авторизация партнера была неуспешной.
  - spamfighter.core.rules.DuplicateRuleError - Правило с таким именем уже было зарегистриовано.
  - spamfighter.core.rules.RuleNotFoundError - Правило с таким именем не найдено.
  - spamfighter.plugin.PluginAmbiguityError - Найдено более одного плагина с указанным именем.
  - spamfighter.plugin.PluginNotFoundError - Не найден плагин с указанным именем.
  - spamfighter.utils.config.ParseException - Исключение кидаемое при попытке распарсить файл с некорректной структурой
- Fault
  - spamfighter.txjsonrpc.web.jsonrpc.NoSuchFunction - There is no function by the given name.
- object
  - spamfighter.api.domain.test.test_get.BaseTestObject - Undocumented
    - spamfighter.api.domain.test.test_get.TestObject - Undocumented
  - spamfighter.core.commands.command.Array - Виртуальный тип данных "массив" для сигнатуры команд.
  - spamfighter.core.commands.command.Command - Базовый класс для всех команд.
    - spamfighter.core.commands.partner.PartneredCommand - Команда, обязательным параметром которой является партнер.
      - spamfighter.core.commands.partner.DomainedCommand - Команда, которая в качестве параметра может содержать путь к поддомену,
        - spamfighter.core.commands.test.test_partner.FakeDomainedCommand - Undocumented
      - spamfighter.core.commands.test.test_partner.FakePartneredCommand - Undocumented
    - spamfighter.core.commands.test.test_apiglue.TestPingCommand - Undocumented
    - spamfighter.core.commands.test.test_command.FakeCommand - Undocumented
    - spamfighter.core.commands.test.test_dispatcher.FakeCommand - Undocumented
  - spamfighter.core.commands.command.Command._ParamsWrapper - Класс-обертка для проверки корректности
  - spamfighter.core.commands.partner.PartnerAuthInfo - Класс, хранящий информации об авторизации партнера.
  - spamfighter.core.commands.test.test_command.FakeSerializable - Undocumented
  - spamfighter.core.commands.test.test_serialize.INotSerializableInterface - Undocumented
  - spamfighter.core.commands.test.test_serialize.SerializabeClass - Undocumented
  - spamfighter.core.counters.AtomCounterEternal - Одиночный счетчик за "весь период" (с момента создания счетчика).
  - spamfighter.core.counters.AtomCounterPeriod - Одиночный счетчик, рассчитывающий своё значение за конечный
  - spamfighter.core.counters.Counter - Набор одиночных счетчиков, вместе рассчитывающих одно значение
    - spamfighter.core.counters.AverageCounter - Счетчик, измеряющий среднее значение величины.
      - spamfighter.core.counters.AverageServiceTimeCounter - Счетчик среднего времени обслуживания.
    - spamfighter.core.counters.RequestCounter - Счетчик числа запросов.
    - spamfighter.core.counters.SpeedCounter - Счетчик, измеряющий "скорость" величины (отношение ко времени).
      - spamfighter.core.counters.RequestPerSecondCounter - Счетчик числа запросов в секунду.
    - spamfighter.core.test.test_counters.TestCounter - Undocumented
  - spamfighter.core.domain.BaseDomain - Домен - единица настроек, привязки локальных элементов
  - spamfighter.core.firewall.FirewallMessagePack - Объект, оборачивающий в один параметр Deferred все данные,
  - spamfighter.core.firewall.FirewallStatement - Класс, инкаспилирующий одно правило файрвола.
    - spamfighter.core.firewall.DoFirewallStatement - Реализация правила "do ... mark as ..."
    - spamfighter.core.firewall.SkipFirewallStatement - Реализация правила 'skip to ...'.
    - spamfighter.core.firewall.StopFirewallStatement - Реализация правила 'stop as...'
  - spamfighter.core.firewall.MessageFirewall - "Черный ящик" анализа сообщений по правилам, построенный
  - spamfighter.core.log.LogEntry - Объект отдельной записи в логе.
  - spamfighter.core.log.MessageLog - Лог сообщений, проходящих через сервер.
  - spamfighter.core.message.attribute.Attribute - Атрибуты характеризуют отправителя и получателя сообщений, они могут нести разную информацию.
  - spamfighter.core.message.attribute.AttributeDomain - Домент (тип атрибута).
    - spamfighter.core.message.attribute.IntAttributeDomain - Тип атрибута "целое число".
      - spamfighter.core.message.attribute.UniqueIntAttributeDomain - Уникальный атрибут, тип "целое число".
    - spamfighter.core.message.attribute.IPAttributeDomain - Атрибут, в котором хранится IP.
    - spamfighter.core.message.attribute.TextAttributeDomain - Тип атрибута "текст сообщения". Основной тип атрибутов при анализе сообщений.
  - spamfighter.core.message.message.Message - Сообщение - основная единица обработки для Спамоборца.
    - spamfighter.core.message.message.TaggedMessage - Сообщение с прицепленными к нему тэгами.
  - spamfighter.core.message.message.MessageDomain - Список доменов атрибутов, которые должны быть у сообщения.
  - spamfighter.core.message.serialize.TransitMessage - Вариант сообщения, которое передается в сериализованном представлении
  - spamfighter.core.model.bayes.BayesModel - Модель анализа сообщений по Байесу.
  - spamfighter.core.model.thomas.Bayes - No class docstring; 11/25 methods documented
  - spamfighter.core.null_partner.NullPartner - Партнер, авторизованный без логина/пароля (на доверии).
  - spamfighter.core.null_partner.NullPartnerAuthorizer - Провайдер авторизации партнеров без логина/пароля (на доверии).
  - spamfighter.core.rules.RulesFactory - Фабрика правил анализа сообщений. Регистрирует правила
  - spamfighter.core.storage.dbm.DBMStorage - Надежное хранилище ключей. Элементы хранилища хранятся в BDB (`anydbm`) базе данных
  - spamfighter.core.storage.dbm.DomainedDBMStorage - Надежное хранилище ключей. Вариант с привязкой к домену.
  - spamfighter.core.storage.memory.DomainMemoryStorage - Хранилище в памяти, которое располагается в домене.
  - spamfighter.core.storage.memory.MemoryStorage - Хранилище пар (ключ, значение) в памяти. Каждая
  - spamfighter.core.test.test_rules.RuleTestFactoryClass - Undocumented
  - spamfighter.plugins.null_partner_authorizer_provider.NullPartnerAuthorizerProvider - Провайдер авторизации партнеров без логинов/паролей.
  - spamfighter.plugins.sample_domain_provider.SampleDomainProvider - Провайдер статического дефолтного домена.
  - spamfighter.plugins.static_domain_provider.StaticDefaultDomainProvider - Провайдер статического дефолтного домена.
  - spamfighter.rules.model.ModelRule - Базовый класс для правило, использующее модель анализа сообщений.
    - spamfighter.rules.model.modelClassify - Классификация сообщения по модели: истинно, если модель сообщает, что сообщение
    - spamfighter.rules.model.modelTrain - Обучить модель на сообщении: всегда истинно.
  - spamfighter.rules.validate.regexpCheck - Правило проверки текст сообщение на соответствие регулярному выражению.
  - spamfighter.test.plugins.plugin_test_1.TestPlugin1 - Undocumented
  - spamfighter.test.plugins.plugin_test_2.TestPlugin2 - Undocumented
  - spamfighter.txjsonrpc.jsonrpclib.SimpleParser - Undocumented
  - spamfighter.txjsonrpc.jsonrpclib.SimpleUnmarshaller - Undocumented
  - spamfighter.utils.test.test_registrator.TestClass - Undocumented
- RuntimeError
  - spamfighter.txjsonrpc.netstring.test.test_jsonrpc.TestRuntimeError - Undocumented
  - spamfighter.txjsonrpc.web.test.test_jsonrpc.TestRuntimeError - Undocumented
- spamfighter.core.commands.apiglue.API_Glue - Базовый класс, обеспечивающий связь XML-RPC и JSON-RPC реализаций на базе
  - spamfighter.core.commands.apiglue.JSONRPC_API_Glue - Ресурс JSON-RPC (Twisted Web), который обрабатывает команды нашего API (минуя стандартные механизмы поиска функции).
  - spamfighter.core.commands.apiglue.XMLRPC_API_Glue - Ресурс XML-RPC (Twisted Web), который обрабатывает команды нашего API (минуя стандартные механизмы поиска функции).
- spamfighter.core.commands.Command
  - spamfighter.api.info.version.InfoVersionCommand - Реализация команды `sf.info.version`.
- spamfighter.core.commands.DomainedCommand
  - spamfighter.api.domain.children.DomainChildrenCommand - Реализация команды `sf.domain.children`.
  - spamfighter.api.domain.get.DomainGetCommand - Реализация команды `sf.domain.get`.
  - spamfighter.api.domain.list.DomainListCommand - Реализация команды `sf.domain.list`.
  - spamfighter.api.message.firewall.FirewallCommand - Базовая команда работы с firewall
    - spamfighter.api.message.firewall.FirewallRulesCheckCommand - Реализация команды `sf.message.firewall.rules.check`.
    - spamfighter.api.message.firewall.FirewallRulesGetCommand - Реализация команды `sf.message.firewall.rules.get`.
    - spamfighter.api.message.firewall.FirewallRulesSetCommand - Реализация команды `sf.message.firewall.rules.set`.
    - spamfighter.api.message.test.test_firewall.FakeFirewallCommand - Undocumented
  - spamfighter.api.message.input.MessageInputCommand - Реализация команды `sf.message.input`.
  - spamfighter.api.message.log.MessageLogFetchCommand - Команда `sf.message.log.fetch`.
  - spamfighter.core.model.command.ModelBaseCommand - Базовый класс команд, упраявляющих моделью.
    - spamfighter.api.model.classify.ModelClassifyCommand - Реализация команды `sf.model.classify`.
    - spamfighter.api.model.train.ModelTrainCommand - Реализация команды `sf.model.train`.
    - spamfighter.core.model.test.test_command.FakeModelCommand - Undocumented
- spamfighter.core.model.test.Texts - Набор текстов для тестирования модели.
- spamfighter.core.model.thomas.Tokenizer - A simple regex-based whitespace tokenizer.
- spamfighter.core.storage.test.base.ExpirableStorageTestMixin - Тест на `spamfighter.interfaces.IExpirableStorage`.
  - spamfighter.core.storage.test.test_dbm.DBMStorageTestCase - Тест на `spamfighter.core.storage.dbm.DBMStorage`.
  - spamfighter.core.storage.test.test_dbm.DomainedDBMStorageTestCase - Тест на `spamfighter.core.storage.dbm.DomainedDBMStorage`.
  - spamfighter.core.storage.test.test_memory.DomainMemoryStorageTestCase - Тест на `spamfighter.core.storage.memory.DomainMemoryStorage`.
  - spamfighter.core.storage.test.test_memory.MemoryStorageTestCase - Тест на `spamfighter.core.storage.memory.MemoryStorage`.
- spamfighter.txjsonrpc.netstring.jsonrpc.Proxy - A Proxy for making remote JSON-RPC calls.
- spamfighter.txjsonrpc.web.jsonrpc.Handler - Handle a JSON-RPC request and store the state for a request in progress.
- spamfighter.txjsonrpc.web.jsonrpc.Proxy - A Proxy for making remote JSON-RPC calls.
- twisted.internet.protocol.ClientFactory
  - spamfighter.txjsonrpc.netstring.jsonrpc.QueryFactory - Undocumented
  - spamfighter.txjsonrpc.web.jsonrpc.QueryFactory - Undocumented
- twisted.internet.protocol.ServerFactory
  - spamfighter.txjsonrpc.netstring.jsonrpc.RPCFactory - Undocumented
- twisted.protocols.basic.NetstringReceiver
  - spamfighter.txjsonrpc.netstring.jsonrpc.JSONRPC - A protocol that implements JSON-RPC.
    - spamfighter.txjsonrpc.netstring.jsonrpc.JSONRPCIntrospection - Implement the JSON-RPC Introspection API.
    - spamfighter.txjsonrpc.netstring.test.test_jsonrpc.Test - No class docstring; 3/10 methods documented
  - spamfighter.txjsonrpc.netstring.jsonrpc.QueryProtocol - Undocumented
- twisted.trial.unittest.TestCase
  - spamfighter.api.domain.test.test_children.DomainChildrenCommandTestCase - Тест на `spamfighter.api.domain.children.DomainChildrenCommand`.
  - spamfighter.api.domain.test.test_get.DomainGetCommandTestCase - Тест на `spamfighter.api.domain.get.DomainGetCommand`.
  - spamfighter.api.domain.test.test_list.DomainListCommandTestCase - Тест на `spamfighter.api.domain.list.DomainListCommand`.
  - spamfighter.api.info.test.test_version.InfoVersionTestCase - Тест на `spamfighter.api.info.version.InfoVersionCommand`.
  - spamfighter.api.message.test.test_firewall.FirewallCommandTestCase - Тест на `spamfighter.api.message.firewall.FirewallCommand`.
  - spamfighter.api.message.test.test_firewall.FirewallRulesCheckCommandTestCase - Тест на `spamfighter.api.message.firewall.FirewallRulesCheckCommand`.
  - spamfighter.api.message.test.test_firewall.FirewallRulesGetCommandTestCase - Тест на `spamfighter.api.message.firewall.FirewallRulesGetCommand`.
  - spamfighter.api.message.test.test_firewall.FirewallRulesSetCommandTestCase - Тест на `spamfighter.api.message.firewall.FirewallRulesSetCommand`.
  - spamfighter.api.message.test.test_input.MessageInputCommandTestCase - Тест на `spamfighter.api.message.input.MessageInputCommand`.
  - spamfighter.api.message.test.test_log.MessageLogFetchCommandTestCase - Тест на `spamfighter.api.message.log.MessageLogFetchCommand`.
  - spamfighter.api.model.test.test_classify.ModelClassifyCommandTestCase - Тест на `spamfighter.api.model.classify.ModelClassifyCommand`.
  - spamfighter.api.model.test.test_train.ModelTrainCommandTestCase - Тест на `spamfighter.api.model.train.ModelTrainCommand`.
  - spamfighter.core.commands.test.test_apiglue.JSON_RPCTestCase - Тест на `spamfighter.core.commands.apiglue.JSONRPC_API_Glue`.
  - spamfighter.core.commands.test.test_apiglue.XML_RPCTestCase - Тест на `spamfighter.core.commands.apiglue.XMLRPC_API_Glue`.
  - spamfighter.core.commands.test.test_command.CommandTestCase - Тест на `spamfighter.core.commands.command.Command`.
  - spamfighter.core.commands.test.test_dispatcher.CommandDispatchTestCase - Тестируем диспетчеризацию комманд.
  - spamfighter.core.commands.test.test_partner.DomainedCommandTestCase - Тест на `spamfighter.core.commands.partner.DomainedCommand`.
  - spamfighter.core.commands.test.test_partner.PartneredCommandTestCase - Тест на `spamfighter.core.commands.partner.PartneredCommand`.
  - spamfighter.core.commands.test.test_serialize.DateTimeTestCase - Тесты на `spamfighter.core.commands.serialize.DateTime`.
  - spamfighter.core.commands.test.test_serialize.RegisterTestCase - Тесты на `spamfighter.core.commands.serialize.register_serializer`, `spamfighter.core.commands.serialize.get_serializer`.
  - spamfighter.core.message.test.test_attribute.AttributeDomainTestCase - Тест на `spamfighter.core.message.attribute.AttributeDomain`.
  - spamfighter.core.message.test.test_attribute.AttributeTestCase - Тест на `spamfighter.core.message.attribute.Attribute`.
  - spamfighter.core.message.test.test_attribute.IntAttributeDomainTestCase - Тест на `spamfighter.core.message.attribute.IntAttributeDomain`.
  - spamfighter.core.message.test.test_attribute.TextAttributeDomainTestCase - Тест на `spamfighter.core.message.attribute.TextAttributeDomain`.
  - spamfighter.core.message.test.test_message.MessageDomainTestCase - Тест на `spamfighter.core.message.message.MessageDomain`.
  - spamfighter.core.message.test.test_message.MessageTestCase - Тест на `spamfighter.core.message.message.Message`.
  - spamfighter.core.message.test.test_message.TaggedMessageTestCase - Тест на `spamfighter.core.message.message.TaggedMessage`.
  - spamfighter.core.message.test.test_serialize.TransitMessageTestCase - Тест на `spamfighter.core.message.TransitMessage`.
  - spamfighter.core.model.test.test_bayes.BayesModelTestCase - Тест на `spamfighter.core.model.dm.BayesModel`.
  - spamfighter.core.model.test.test_command.ModelBaseCommandTestCase - Тест на `spamfighter.core.model.command.ModelBaseCommand`.
  - spamfighter.core.storage.test.test_dbm.DBMStorageTestCase - Тест на `spamfighter.core.storage.dbm.DBMStorage`.
  - spamfighter.core.storage.test.test_dbm.DomainedDBMStorageTestCase - Тест на `spamfighter.core.storage.dbm.DomainedDBMStorage`.
  - spamfighter.core.storage.test.test_memory.DomainMemoryStorageTestCase - Тест на `spamfighter.core.storage.memory.DomainMemoryStorage`.
  - spamfighter.core.storage.test.test_memory.MemoryStorageTestCase - Тест на `spamfighter.core.storage.memory.MemoryStorage`.
  - spamfighter.core.test.test_counters.AtomCounterEternalTestCase - Тест на `spamfighter.core.counters.AtomCounterEternal`.
  - spamfighter.core.test.test_counters.AtomCounterPeriodTestCase - Тест на `spamfighter.core.counters.AtomCounterPeriod`.
  - spamfighter.core.test.test_counters.CounterTestCase - Тест на `spamfighter.core.counters.Counter`.
  - spamfighter.core.test.test_domain.BaseDomainTestCase - Тест на `spamfighter.core.domain.BaseDomain`.
  - spamfighter.core.test.test_domain.DefaultDomainTestCase - Тест на предоставление домена по умолчанию.
  - spamfighter.core.test.test_firewall.DoFirewallStatementTestCase - Тест на `spamfighter.core.firewall.DoFirewallStatement`.
  - spamfighter.core.test.test_firewall.FirewallStatementTestCase - Тест на `spamfighter.core.firewall.FirewallStatement`.
  - spamfighter.core.test.test_firewall.MessageFirewallTestCase - Тест на `spamfighter.core.firewall.MessageFirewall`.
  - spamfighter.core.test.test_firewall.SkipFirewallStatementTestCase - Тест на `spamfighter.core.firewall.SkipFirewallStatement`.
  - spamfighter.core.test.test_firewall.StopFirewallStatementTestCase - Тест на `spamfighter.core.firewall.StopFirewallStatement`.
  - spamfighter.core.test.test_log.LogEntryTestCase - Тест на `spamfighter.core.log.LogEntry`.
  - spamfighter.core.test.test_log.MessageLogTestCase - Тест на `spamfighter.core.log.MessageLog`.
  - spamfighter.core.test.test_null_partner.NullPartnerAuthorizerTestCase - Тест на `spamfighter.core.null_partner.NullPartnerAuthorizer`.
  - spamfighter.core.test.test_null_partner.NullPartnerTestCase - Тест на `spamfighter.core.null_partner.NullPartner`.
  - spamfighter.core.test.test_partner.PartnerAuthorizerTestCase - Тест на предоставление механизма авторизации по умолчанию.
  - spamfighter.core.test.test_rules.RulesFactoryTestCase - Тест на `spamfighter.core.rules.RulesFactory`.
  - spamfighter.rules.test.test_analyze.AnalyzeRulesTestCase - Тест на `spamfighter.rules.text`.
  - spamfighter.rules.test.test_frequency.FrequencyRulesTestCase - Тест на `spamfighter.rules.frequency`.
  - spamfighter.rules.test.test_log.MessageLogPutTestCase - Тест на `spamfighter.rules.log.messageLogPut`.
  - spamfighter.rules.test.test_model.ModelRuleTestCase - Тест на `spamfighter.rules.model`.
  - spamfighter.rules.test.test_validate.ValidateRulesTestCase - Тест на `spamfighter.rules.validate`.
  - spamfighter.txjsonrpc.netstring.test.test_jsonrpc.JSONRPCTestCase - Undocumented
    - spamfighter.txjsonrpc.netstring.test.test_jsonrpc.JSONRPCTestIntrospection - Undocumented
  - spamfighter.txjsonrpc.web.test.test_jsonrpc.JSONRPCClientErrorHandling - Undocumented
  - spamfighter.txjsonrpc.web.test.test_jsonrpc.JSONRPCTestCase - Undocumented
    - spamfighter.txjsonrpc.web.test.test_jsonrpc.JSONRPCTestAuthenticated - Test with authenticated proxy. We run this with the same inout/ouput as
    - spamfighter.txjsonrpc.web.test.test_jsonrpc.JSONRPCTestCase2 - Test with proxy that doesn't add a slash.
    - spamfighter.txjsonrpc.web.test.test_jsonrpc.JSONRPCTestIntrospection - Undocumented
  - spamfighter.utils.test.test_time.InaccurateTimeTestCase - Тесты на `spamfighter.utils.time` - вариант расчета времени с точностью до 1 с.
  - spamfighter.utils.test.test_time.TestTimerTestCase - Тесты на `spamfighter.utils.time` - таймер для тестов
- twisted.web.http.HTTPClient
  - spamfighter.txjsonrpc.web.jsonrpc.QueryProtocol - Undocumented
- twisted.web.resource.Resource
  - spamfighter.txjsonrpc.web.jsonrpc.JSONRPC - A resource that implements JSON-RPC.
    - spamfighter.core.commands.apiglue.JSONRPC_API_Glue - Ресурс JSON-RPC (Twisted Web), который обрабатывает команды нашего API (минуя стандартные механизмы поиска функции).
    - spamfighter.txjsonrpc.web.jsonrpc.JSONRPCIntrospection - Implement a JSON-RPC Introspection API.
    - spamfighter.txjsonrpc.web.test.test_jsonrpc.Test - No class docstring; 3/10 methods documented
      - spamfighter.txjsonrpc.web.test.test_jsonrpc.TestAuthHeader - This is used to get the header info so that we can test
- twisted.web.xmlrpc.XMLRPC
  - spamfighter.core.commands.apiglue.XMLRPC_API_Glue - Ресурс XML-RPC (Twisted Web), который обрабатывает команды нашего API (минуя стандартные механизмы поиска функции).
- type
  - spamfighter.core.commands.partner.CommandParamMergerMeta - Мета-тип, который собирает вместе сигнатуру
- unittest.TestCase
  - spamfighter.plugins.test.test_null_partner_authorizer_provider.NullPartnerAuthorizerProviderTestCase - Тест на `spamfighter.plugins.null_partner_authorizer_provider.NullPartnerAuthorizerProvider`.
  - spamfighter.plugins.test.test_static_doman_provider.StaticDefaultDomainProviderTestCase - Тест на `spamfighter.plugins.static_domain_provider.StaticDefaultDomainProvider`.
  - spamfighter.test.test_plugin.PluginTestCase - Тест на `spamfighter.plugin.loadPlugin`.
  - spamfighter.utils.test.test_config.ConfigTestCase - Тесты на `spamfighter.utils.config`.
  - spamfighter.utils.test.test_registrator.RegistratorTestCase - Тесты на `spamfighter.utils.registrator.registrator`.
- ValueError
  - spamfighter.txjsonrpc.netstring.test.test_jsonrpc.TestValueError - Undocumented
  - spamfighter.txjsonrpc.web.test.test_jsonrpc.TestValueError - Undocumented
- xmlrpclib.Fault
  - spamfighter.txjsonrpc.jsonrpclib.Fault - Undocumented
    - spamfighter.txjsonrpc.jsonrpclib.NoSuchFunction - There is no function by the given name.
- xmlrpclib.ServerProxy
  - spamfighter.txjsonrpc.jsonrpclib.ServerProxy - No class docstring; 1/2 methods documented
- xmlrpclib.Transport
  - spamfighter.txjsonrpc.jsonrpclib.Transport - Handles an HTTP transaction to an XML-RPC server.
- zope.interface.Interface
  - spamfighter.api.domain.test.test_get.I1 - Undocumented
  - spamfighter.api.domain.test.test_get.I2 - Undocumented
  - spamfighter.core.commands.command.ICommand - Интерфейс команд. Этот интерфейс обязаны реализовывать
  - spamfighter.core.commands.serialize.ISerializable - Сущность, которая может передаваться в команде (и, соответственно, должна
    - spamfighter.core.commands.partner.IPartnerAuthInfo - Информация об авторизации партнера.
    - spamfighter.core.commands.test.test_command.IFakeSerializable - Undocumented
    - spamfighter.core.commands.test.test_serialize.ISerializableInterface - Undocumented
    - spamfighter.core.message.serialize.ITransitMessage - Вариант сообщения, которое передается в сериализованном представлении
  - spamfighter.core.counters.IAtomCounter - Одиночный счетчик (одно значение). Счетчик рассчитывает своё
  - spamfighter.core.counters.ICounter - Счетчик, аккумулирующий информацию по группе одиночных счетчиков `IAtomCounter`.
  - spamfighter.interfaces.IAttribute - Атрибуты характеризуют отправителя и получателя сообщений, они могут нести разную информацию.
  - spamfighter.interfaces.IAttributeDomain - Домент (тип атрибута).
  - spamfighter.interfaces.IDomain - Домен - единица настроек, привязки локальных элементов
  - spamfighter.interfaces.IDomainBindable - Интерфейс объекта, который при помещении в домен должен
  - spamfighter.interfaces.IExpirableStorage - Ненадежное хранилище, в котором данные имеют ограниченный срок жизни. Хранилище
  - spamfighter.interfaces.ILogEntry - Отдельная запись в логе сообщений.
  - spamfighter.interfaces.IMessage - Сообщение - основная единица обработки для Спамоборца.
    - spamfighter.interfaces.ITaggedMessage - Сообщение с прицепленными к нему тэгами.
  - spamfighter.interfaces.IMessageAnalyzer - Некоторый черный ящик анализа сообщений. Получает на вход
  - spamfighter.interfaces.IMessageDomain - Список доменов атрибутов, которые должны быть у сообщения.
  - spamfighter.interfaces.IMessageFirewall - Маркерный интерфейс файрвола.
  - spamfighter.interfaces.IMessageLog - Лог сообщений, проходящих через сервер.
  - spamfighter.interfaces.IModel - Интерфейс модели анализа сообщений.
  - spamfighter.interfaces.IPartner - Партнер - единица авторизации относительно API веб-сервиса СпамоБорца.
  - spamfighter.interfaces.IPartnerAuthorizer - Модуль авторизации партнеров. Способ авторизации не задается интерфейсом, но
  - spamfighter.interfaces.IPartnerRegistrator - Модуль регистрации партнеров с использованием логинов и паролей.
  - spamfighter.interfaces.IStorage - Базовый интерфейс хранилища.
    - spamfighter.interfaces.IPersistentStorage - Маркерный интерфейс хранилища, которое гарантирует
    - spamfighter.interfaces.IUnreliableStorage - Маркерный интерфейс хранилища, которое не гарантирует
  - spamfighter.plugin.INamedPlugin - Базовый интерфейс плагинов: плагин, который имеет имя.
    - spamfighter.plugin.IDefaultDomainProvider - Интерфейс плагина, возвращающего ссылку на провайдер домена по умолчанию.
    - spamfighter.plugin.IPartnerAuthorizerProvider - Интерфейс плагина, возвращающего ссылку на механизм авторизации партнеров.
    - spamfighter.test.plugins.ITestPlugin1 - Интерфейс тестовых плагинов #1.
    - spamfighter.test.plugins.ITestPlugin2 - Интерфейс тестовых плагинов #2.
    - spamfighter.test.plugins.ITestPlugin3 - Интерфейс тестовых плагинов #3.